// Copyright (C) 2022 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/foundation.dart';

import 'package:wyatt_authentication_bloc/src/form/form_input.dart';

@immutable
class FormEntry {
  const FormEntry(this.field, this.input, {this.export = true, this.fieldName});

  final String field;
  final FormInput input;
  final bool export;
  final String? fieldName;

  FormEntry copyWith({
    String? field,
    FormInput? input,
    bool? export,
    String? fieldName,
  }) {
    return FormEntry(
      field ?? this.field,
      input ?? this.input,
      export: export ?? this.export,
      fieldName: fieldName ?? this.fieldName,
    );
  }

  FormEntry clone() {
    return FormEntry(
      field,
      input,
      export: export,
      fieldName: fieldName,
    );
  }

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) return true;

    return other is FormEntry &&
        other.field == field &&
        other.input == input &&
        other.export == export &&
        other.fieldName == fieldName;
  }

  @override
  int get hashCode {
    return field.hashCode ^
        input.hashCode ^
        export.hashCode ^
        fieldName.hashCode;
  }

  @override
  String toString() {
    // ignore: lines_longer_than_80_chars
    return 'FormEntry(field: $field, input: $input, export: $export, fieldName: $fieldName)';
  }
}
