// Copyright (C) 2022 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:wyatt_authentication_bloc/wyatt_authentication_bloc.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  const Email email = Email.dirty('email');
  const Password password = Password.dirty('password');

  group('SignInState', () {
    test('supports value comparisons', () {
      expect(const SignInState(), const SignInState());
    });

    test('returns same object when no properties are passed', () {
      expect(const SignInState().copyWith(), const SignInState());
    });

    test('returns object with updated status when status is passed', () {
      expect(
        const SignInState().copyWith(status: FormStatus.pure),
        const SignInState(),
      );
    });

    test('returns object with updated email when email is passed', () {
      expect(
        const SignInState().copyWith(email: email),
        const SignInState(email: email),
      );
    });

    test('returns object with updated password when password is passed', () {
      expect(
        const SignInState().copyWith(password: password),
        const SignInState(password: password),
      );
    });
  });
}
