// Copyright (C) 2022 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:async';

import 'package:bloc/bloc.dart';
import 'package:meta/meta.dart';
import 'package:wyatt_form_bloc/src/enums/enums.dart';
import 'package:wyatt_form_bloc/src/form/form.dart';

part 'form_data_state.dart';

class FormDataCubit extends Cubit<FormDataState> {
  final Future<bool> Function(FormDataState state)? _onSubmit;

  FormDataCubit({
    required FormData entries,
    Future<bool> Function(FormDataState state)? onSubmit,
  })  : _onSubmit = onSubmit,
        super(FormDataState(data: entries));

  void dataChanged<T>(String field, FormInput dirtyValue) {
    final _form = state.data.clone();

    if (_form.contains(field)) {
      _form.update(field, dirtyValue);
    } else {
      throw Exception('Form field $field not found');
    }

    emit(
      state.copyWith(
        data: _form,
        status: _form.validate(),
      ),
    );
  }

  void updateFormData(
    FormData data, {
    SetOperation operation = SetOperation.replace,
  }) {
    FormData _form = data;

    switch (operation) {
      case SetOperation.replace:
        _form = data;
        break;
      case SetOperation.difference:
        _form = state.data.difference(data);
        break;
      case SetOperation.intersection:
        _form = state.data.intersection(data);
        break;
      case SetOperation.union:
        _form = state.data.union(data);
        break;
    }

    emit(
      state.copyWith(
        data: _form,
        status: _form.validate(),
      ),
    );
  }

  Future<void> submitForm() async {
    unawaited(
      _onSubmit?.call(state).then((bool reemit) {
        if (reemit) {
          emit(state);
        }
      }),
    );
  }
}
